@@ -302,8 +302,8 @@ L.Storage.DataLayer = L.Class.extend({
         }
         var self = this,
             url = this.map.localizeUrl(this.options.remoteData.url);
-        if (this.options.remoteData.proxy && this.map.options.urls.ajax_proxy) {
-            url = L.Util.template(this.map.options.urls.ajax_proxy, {url: encodeURIComponent(url)});
+        if (this.options.remoteData.proxy) {
+            url = this.map.proxyUrl(url);
         }
         this.map.ajax({
             uri: url,
@@ -483,7 +483,12 @@ L.Storage.DataLayer = L.Class.extend({
 
         switch (geometry.type) {
             case 'Point':
-                latlng = L.GeoJSON.coordsToLatLng(coords);
+                try {
+                    latlng = L.GeoJSON.coordsToLatLng(coords);
+                } catch (e) {
+                    console.error('Invalid latlng object from', coords);
+                    break;
+                }
                 layer = this._pointToLayer(geojson, latlng);
                 break;
             case 'LineString':
